@@ -1,11 +1,13 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2017-2022, by Samuel Williams.
+# Copyright, 2017-2024, by Samuel Williams.
 
-require_relative 'container/controller'
+require_relative "container/controller"
 
+# @namespace
 module Async
+	# @namespace
 	module Container
 	end
 end
