@@ -1,14 +1,15 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2019-2022, by Samuel Williams.
+# Copyright, 2019-2024, by Samuel Williams.
 
-require 'async/reactor'
+require "async/reactor"
 
 module Async
 	module Container
 		# Tracks various statistics relating to child instances in a container.
 		class Statistics
+			# Initialize the statistics all to 0.
 			def initialize
 				@spawns = 0
 				@restarts = 0
